@@ -1,14 +1,13 @@
-__version__ = "0.5.20"
+__version__ = "0.5.21"
 
 from .core import (
     magicclass,
     magicmenu,
     magiccontext,
-    magictoolbar, 
+    magictoolbar,
     Parameters,
-    Bound,
-    build_help
-    )
+    build_help,
+)
 
 from .wrappers import (
     set_options,
@@ -18,12 +17,12 @@ from .wrappers import (
     bind_key,
     confirm,
     nogui,
-    )
+)
 
 from .fields import field, vfield
 from .gui._base import wraps, defaults, MagicTemplate, PopUpMode
-from ._typing import WidgetType
+from .types import WidgetType, Bound, Color, Optional
 from .gui.keybinding import Key
 from . import widgets, utils
 
-from magicgui import *
\ No newline at end of file
+from magicgui import *
