@@ -5,12 +5,9 @@ from macrokit import register_type, symbol, Expr
 
 register_type(Viewer, lambda e: "viewer")
 
+
 @register_type(Layer)
 def _get_layer(layer: Layer):
     vw = symbol(current_viewer())
-    expr = Expr("getitem", 
-                [Expr("getattr", 
-                      [vw,
-                       "layers"]), 
-                 layer.name])
+    expr = Expr("getitem", [Expr("getattr", [vw, "layers"]), layer.name])
     return expr
