@@ -7,6 +7,7 @@ import inspect
 from typing import TypedDict
 from .utils import get_signature
 
+
 class AdditionalOptions(TypedDict):
     record: bool
     keybinding: str
@@ -16,10 +17,12 @@ class AdditionalOptions(TypedDict):
     gui: bool
 
 
-def upgrade_signature(func, 
-                      gui_options: dict = None, 
-                      caller_options: WidgetOptions = None,
-                      additional_options: AdditionalOptions = None):
+def upgrade_signature(
+    func,
+    gui_options: dict = None,
+    caller_options: WidgetOptions = None,
+    additional_options: AdditionalOptions = None,
+):
     """
     Upgrade function signature to MagicMethodSignature. The input function may have
     a inspect.Signature or magicgui.signature.Magicsignature.
@@ -43,12 +46,12 @@ def upgrade_signature(func,
     gui_options = gui_options or {}
     caller_options = caller_options or {}
     additional_options = additional_options or {}
-    
+
     sig = get_signature(func)
-    
+
     new_gui_options = MagicMethodSignature.get_gui_options(sig).copy()
     new_gui_options.update(gui_options)
-    
+
     new_caller_options = getattr(sig, "caller_options", {}).copy()
     new_caller_options.update(caller_options)
 
@@ -56,11 +59,11 @@ def upgrade_signature(func,
     new_additional_options.update(additional_options)
 
     func.__signature__ = MagicMethodSignature.from_signature(
-            sig, 
-            gui_options=new_gui_options, 
-            caller_options=new_caller_options,
-            additional_options=new_additional_options
-            )
+        sig,
+        gui_options=new_gui_options,
+        caller_options=new_caller_options,
+        additional_options=new_additional_options,
+    )
 
     return func
 
@@ -86,48 +89,62 @@ class MagicMethodSignature(MagicSignature):
     """
     This class also retains parameter options for PushButton itself, aside from the FunctionGui options
     that will be needed when the button is pushed.
-    """    
+    """
+
     def __init__(
         self,
-        parameters = None,
+        parameters=None,
         *,
-        return_annotation = inspect.Signature.empty,
+        return_annotation=inspect.Signature.empty,
         gui_options: dict[str, dict] = None,
         caller_options: dict[str] = None,
         additional_options: dict[str] = None,
     ):
-        super().__init__(parameters=parameters, return_annotation=return_annotation, gui_options=gui_options)
+        super().__init__(
+            parameters=parameters,
+            return_annotation=return_annotation,
+            gui_options=gui_options,
+        )
         self.caller_options = caller_options or {}
         self.additional_options = additional_options or {}
-    
+
     @classmethod
-    def from_signature(cls, sig: inspect.Signature, gui_options=None, caller_options=None,
-                       additional_options=None) -> MagicMethodSignature:
+    def from_signature(
+        cls,
+        sig: inspect.Signature,
+        gui_options=None,
+        caller_options=None,
+        additional_options=None,
+    ) -> MagicMethodSignature:
         if not isinstance(sig, inspect.Signature):
             raise TypeError("'sig' must be an instance of 'inspect.Signature'")
-        
+
         # prepare parameters again
-        parameters = {k: inspect.Parameter(param.name,
-                                           param.kind,
-                                           default=param.default,
-                                           annotation=param.annotation) 
-                      for k, param in sig.parameters.items()}
-        
+        parameters = {
+            k: inspect.Parameter(
+                param.name,
+                param.kind,
+                default=param.default,
+                annotation=param.annotation,
+            )
+            for k, param in sig.parameters.items()
+        }
+
         return cls(
             list(parameters.values()),
             return_annotation=sig.return_annotation,
             gui_options=gui_options,
             caller_options=caller_options,
             additional_options=additional_options,
-            )
-    
+        )
+
     @classmethod
-    def get_gui_options(cls, self: inspect.Signature|MagicSignature):
+    def get_gui_options(cls, self: inspect.Signature | MagicSignature):
         if type(self) is inspect.Signature:
             return {}
         else:
             return {k: v.options for k, v in self.parameters.items()}
-    
+
     def replace(
         self,
         *,
@@ -145,8 +162,10 @@ class MagicMethodSignature(MagicSignature):
         if return_annotation is _void:
             return_annotation = self.return_annotation
         cls = type(self)
-        return cls(parameters,
-                   return_annotation=return_annotation,
-                   gui_options = cls.get_gui_options(self),
-                   caller_options = self.caller_options,
-                   additional_options = self.additional_options)
+        return cls(
+            parameters,
+            return_annotation=return_annotation,
+            gui_options=cls.get_gui_options(self),
+            caller_options=self.caller_options,
+            additional_options=self.additional_options,
+        )
