@@ -1,30 +1,122 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Iterable, MutableSequence
+from typing import TYPE_CHECKING, Iterable, MutableSequence, Any
 from qtpy.QtWidgets import QTabWidget, QLineEdit, QMenu
 from qtpy.QtGui import QTextCursor
 from qtpy.QtCore import Qt
-from magicgui.widgets import PushButton, TextEdit, Table
-
-from .utils import FreeWidget
+from magicgui.widgets import (
+    PushButton,
+    TextEdit,
+    Table,
+    Container,
+    CheckBox,
+    create_widget,
+)
+from magicgui.widgets._bases.value_widget import ValueWidget, UNSET
+from .utils import FreeWidget, merge_super_sigs
 
 if TYPE_CHECKING:
     from qtpy.QtWidgets import QTextEdit
     from matplotlib.axes import Axes
 
+
+@merge_super_sigs
+class OptionalWidget(Container):
+    """
+    A container that can represent optional argument.
+
+    Parameters
+    ----------
+    widget_type : ValueWidget type
+        Type of inner value widget.
+    text : str, optional
+        Text of checkbox.
+    value : Any
+        Initial value.
+    options : dict, optional
+        Widget options of the inner value widget.
+    """
+
+    def __init__(
+        self,
+        widget_type: type[ValueWidget] | None = None,
+        text: str = None,
+        layout="vertical",
+        nullable=True,
+        value=UNSET,
+        options=None,
+        **kwargs,
+    ):
+        if text is None:
+            text = "Use default value"
+        if options is None:
+            options = {}
+        self._checkbox = CheckBox(text=text, value=True)
+
+        if widget_type is None:
+            self._inner_value_widget = create_widget(
+                annotation=kwargs["annotation"],
+                options=options,
+            )
+        else:
+            self._inner_value_widget = create_widget(
+                widget_type=widget_type,
+                options=options,
+            )
+
+        super().__init__(
+            layout=layout,
+            widgets=(self._checkbox, self._inner_value_widget),
+            labels=True,
+            **kwargs,
+        )
+
+        @self._checkbox.changed.connect
+        def _toggle_visibility(v: bool):
+            self._inner_value_widget.visible = not v
+
+        self.value = value
+
+    @property
+    def value(self) -> Any:
+        if not self._checkbox.value:
+            return self._inner_value_widget.value
+        else:
+            return None
+
+    @value.setter
+    def value(self, v: Any) -> None:
+        if v is None or v is UNSET:
+            self._checkbox.value = True
+            self._inner_value_widget.visible = False
+        else:
+            self._inner_value_widget.value = v
+            self._checkbox.value = False
+            self._inner_value_widget.visible = True
+
+    @property
+    def text(self) -> str:
+        return self._checkbox.text
+
+    @text.setter
+    def text(self, v: str) -> None:
+        self._checkbox.text = v
+
+
 class Figure(FreeWidget):
-    """
-    A matplotlib figure canvas.
-    """
-    def __init__(self, 
-                 nrows: int = 1,
-                 ncols: int = 1,
-                 figsize: tuple[int, int] = (4, 3),
-                 style = None, 
-                 **kwargs):
+    """A matplotlib figure canvas."""
+
+    def __init__(
+        self,
+        nrows: int = 1,
+        ncols: int = 1,
+        figsize: tuple[int, int] = (4, 3),
+        style=None,
+        **kwargs,
+    ):
         import matplotlib as mpl
         import matplotlib.pyplot as plt
         from matplotlib.backends.backend_qt5agg import FigureCanvas
-        
+
         backend = mpl.get_backend()
         try:
             mpl.use("Agg")
@@ -35,13 +127,13 @@ class Figure(FreeWidget):
                     fig, _ = plt.subplots(nrows, ncols, figsize=figsize)
         finally:
             mpl.use(backend)
-        
+
         super().__init__(**kwargs)
         canvas = FigureCanvas(fig)
         self.set_widget(canvas)
         self.figure = fig
         self.min_height = 40
-        
+
         for name, method in self.__class__.__dict__.items():
             if name.startswith("_") or getattr(method, "__doc__", None) is None:
                 continue
@@ -49,58 +141,58 @@ class Figure(FreeWidget):
             plt_doc = getattr(plt_method, "__doc__", "")
             if plt_doc:
                 method.__doc__ += f"\nOriginal docstring:\n\n{plt_doc}"
-        
+
     def draw(self):
         """Copy of ``plt.draw()``."""
         self.figure.tight_layout()
         self.figure.canvas.draw()
-        
+
     def clf(self):
         """Copy of ``plt.clf``."""
         self.figure.clf()
         self.draw()
-    
+
     def cla(self):
         """Copy of ``plt.cla``."""
         self.ax.cla()
         self.draw()
-    
+
     @property
-    def axes(self) -> "list[Axes]":
+    def axes(self) -> list[Axes]:
         return self.figure.axes
-    
+
     @property
-    def ax(self) -> "Axes":
+    def ax(self) -> Axes:
         try:
             _ax = self.axes[0]
         except IndexError:
             _ax = self.figure.add_subplot(111)
         return _ax
-    
-    def plot(self, *args, **kwargs) -> "Axes":
+
+    def plot(self, *args, **kwargs) -> Axes:
         """Copy of ``plt.plot``."""
         self.ax.plot(*args, **kwargs)
         self.draw()
         return self.ax
-    
-    def scatter(self, *args, **kwargs) -> "Axes":
+
+    def scatter(self, *args, **kwargs) -> Axes:
         """Copy of ``plt.scatter``."""
         self.ax.scatter(*args, **kwargs)
         self.draw()
         return self.ax
-    
+
     def hist(self, *args, **kwargs):
         """Copy of ``plt.hist``."""
         self.ax.hist(*args, **kwargs)
         self.draw()
         return self.ax
-    
+
     def text(self, *args, **kwargs):
         """Copy of ``plt.text``."""
         self.ax.text(*args, **kwargs)
         self.draw()
         return self.ax
-        
+
     def xlim(self, *args, **kwargs):
         """Copy of ``plt.xlim``."""
         ax = self.ax
@@ -118,31 +210,31 @@ class Figure(FreeWidget):
         ret = ax.set_ylim(*args, **kwargs)
         self.draw()
         return ret
-    
-    def imshow(self, *args, **kwargs) -> "Axes":
+
+    def imshow(self, *args, **kwargs) -> Axes:
         """Copy of ``plt.imshow``."""
         self.ax.imshow(*args, **kwargs)
         self.draw()
         return self.ax
-    
+
     def legend(self, *args, **kwargs):
         """Copy of ``plt.legend``."""
         leg = self.ax.legend(*args, **kwargs)
         self.draw()
         return leg
-    
+
     def title(self, *args, **kwargs):
         """Copy of ``plt.title``."""
         title = self.ax.set_title(*args, **kwargs)
         self.draw()
         return title
-    
+
     def xlabel(self, *args, **kwargs):
         """Copy of ``plt.xlabel``."""
         xlabel = self.ax.set_xlabel(*args, **kwargs)
         self.draw()
         return xlabel
-    
+
     def ylabel(self, *args, **kwargs):
         """Copy of ``plt.ylabel``."""
         ylabel = self.ax.set_ylabel(*args, **kwargs)
@@ -151,34 +243,36 @@ class Figure(FreeWidget):
 
 
 class ConsoleTextEdit(TextEdit):
-    """A text edit with console-like setting."""    
+    """A text edit with console-like setting."""
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         from qtpy.QtGui import QFont, QTextOption
+
         self.native: QTextEdit
         font = QFont("Consolas")
         font.setStyleHint(QFont.Monospace)
         font.setFixedPitch(True)
         self.native.setFont(font)
         self.native.setWordWrapMode(QTextOption.NoWrap)
-        
+
         # set tab width
         self.tab_size = 4
-    
+
     @property
     def tab_size(self):
         metrics = self.native.fontMetrics()
         return self.native.tabStopWidth() // metrics.width(" ")
-    
+
     @tab_size.setter
     def tab_size(self, size: int):
         metrics = self.native.fontMetrics()
-        self.native.setTabStopWidth(size*metrics.width(" "))
-        
+        self.native.setTabStopWidth(size * metrics.width(" "))
+
     def append(self, text: str):
         """Append new text."""
         self.native.append(text)
-    
+
     def erase_last(self):
         """Erase the last line."""
         cursor = self.native.textCursor()
@@ -187,19 +281,22 @@ class ConsoleTextEdit(TextEdit):
         cursor.removeSelectedText()
         cursor.deletePreviousChar()
         self.native.setTextCursor(cursor)
-    
+
     @property
     def selected(self) -> str:
         """Return selected string."""
         cursor = self.native.textCursor()
-        return cursor.selectedText().replace(u"\u2029", "\n")
+        return cursor.selectedText().replace("\u2029", "\n")
+
 
 class CheckButton(PushButton):
     """A checkable button."""
+
     def __init__(self, text: str | None = None, **kwargs):
         super().__init__(text=text, **kwargs)
         self.native.setCheckable(True)
 
+
 class _QtSpreadSheet(QTabWidget):
     def __init__(self):
         super().__init__()
@@ -209,35 +306,37 @@ class _QtSpreadSheet(QTabWidget):
         self.tabBar().setContextMenuPolicy(Qt.CustomContextMenu)
         self.tabBar().customContextMenuRequested.connect(self.showContextMenu)
         self._line_edit = None
-    
+
     def addTable(self, table):
         self.addTab(table, f"Sheet {self._n_table}")
         self._n_table += 1
-    
+
     def renameTab(self, index: int, name: str) -> None:
         self.tabBar().setTabText(index, name)
         return None
-    
+
     def editTabBarLabel(self, index: int):
         if index < 0:
             return
         if self._line_edit is not None:
             self._line_edit.deleteLater()
             self._line_edit = None
-            
+
         tabbar = self.tabBar()
         self._line_edit = QLineEdit(self)
-        @self._line_edit.editingFinished.connect        
+
+        @self._line_edit.editingFinished.connect
         def _(_=None):
             self.renameTab(index, self._line_edit.text())
             self._line_edit.deleteLater()
             self._line_edit = None
-        self._line_edit.setText(tabbar.tabText(index))  
+
+        self._line_edit.setText(tabbar.tabText(index))
         self._line_edit.setGeometry(tabbar.tabRect(index))
         self._line_edit.setFocus()
         self._line_edit.selectAll()
         self._line_edit.show()
-    
+
     def showContextMenu(self, point):
         if point.isNull():
             return
@@ -248,23 +347,23 @@ class _QtSpreadSheet(QTabWidget):
         rename_action.triggered.connect(lambda _: self.editTabBarLabel(index))
         delete_action = menu.addAction("Delete")
         delete_action.triggered.connect(lambda _: self.removeTab(index))
-        
+
         menu.exec(tabbar.mapToGlobal(point))
 
 
 class SpreadSheet(FreeWidget, MutableSequence[Table]):
     """A simple spread sheet widget."""
-    
+
     def __init__(self):
         super().__init__()
         spreadsheet = _QtSpreadSheet()
         self.set_widget(spreadsheet)
         self.central_widget: _QtSpreadSheet
         self._tables: list[Table] = []
-    
+
     def __len__(self) -> int:
         return self.central_widget.count()
-        
+
     def index(self, item: Table | str):
         if isinstance(item, Table):
             for i, table in enumerate(self._tables):
@@ -283,31 +382,30 @@ class SpreadSheet(FreeWidget, MutableSequence[Table]):
         else:
             raise TypeError
 
-    
     def __getitem__(self, key):
         if isinstance(key, str):
             key = self.index(key)
         return self._tables[key]
-    
+
     def __setitem__(self, key, value):
         raise NotImplementedError
-    
+
     def __delitem__(self, key):
         if isinstance(key, str):
             key = self.index(key)
         self.central_widget.removeTab(key)
         del self._tables[key]
-    
+
     def __iter__(self) -> Iterable[Table]:
         return iter(self._tables)
-        
+
     def insert(self, key: int, value):
         if key < 0:
             key += len(self)
         table = Table(value=value)
         self.central_widget.addTable(table.native)
         self._tables.insert(key, table)
-    
+
     def rename(self, index: int, name: str):
         self.central_widget.renameTab(index, name)
         return None
