@@ -1,37 +1,44 @@
 from __future__ import annotations
-from magicgui.events import Signal
+from psygnal import Signal
 from qtpy.QtWidgets import QFrame, QLabel, QPushButton, QSizePolicy, QHBoxLayout
 from .utils import FreeWidget
 
+
 class Separator(FreeWidget):
     """
     A Separator widget that can be used in both widgets and menus.
     This widget is not actually added to menus or toolbars.
-    """    
+    """
+
     btn_clicked = Signal(bool)
-    
-    def __init__(self, orientation: str = "horizontal", text: str = "", name: str = "", 
-                 button: bool = False):
+
+    def __init__(
+        self,
+        orientation: str = "horizontal",
+        text: str = "",
+        name: str = "",
+        button: bool = False,
+    ):
         super().__init__(name=name)
         self._qtitlebar = _QTitleBar(self.native, text, button)
         self.set_widget(self._qtitlebar)
         if button:
             self._qtitlebar.button.clicked.connect(
                 lambda e: self.btn_clicked.emit(self._qtitlebar.button.isDown())
-                )
-    
+            )
+
     @property
     def btn_text(self):
         return self._qtitlebar.button.text()
-    
+
     @btn_text.setter
     def btn_text(self, value: str):
         self._qtitlebar.button.setText(value)
 
-        
+
 class _QTitleBar(QLabel):
     """See also: napari/_qt/qt_main_window.py."""
-    
+
     def __init__(self, parent, text: str = "", button: bool = False):
         super().__init__(parent)
 
@@ -39,7 +46,8 @@ class _QTitleBar(QLabel):
         line.setFrameShape(QFrame.HLine)
         line.setFrameShadow(QFrame.Sunken)
         line.setObjectName("Separator")
-        line.setStyleSheet("""
+        line.setStyleSheet(
+            """
             QFrame#Separator {
                 background-color: gray;
             }
@@ -49,20 +57,22 @@ class _QTitleBar(QLabel):
         layout = QHBoxLayout()
         layout.setSpacing(4)
         layout.setContentsMargins(8, 1, 8, 0)
-        
+
         if button:
             self.button = QPushButton(self)
             self.button.setFixedWidth(20)
-            self.button.setStyleSheet("QPushButton {"
-                                      "border: 1px solid #555;"
-                                      "border-radius: 10px;"
-                                      "border-style: outset;"
-                                      "padding: 5px"
-                                      "}")
+            self.button.setStyleSheet(
+                "QPushButton {"
+                "border: 1px solid #555;"
+                "border-radius: 10px;"
+                "border-style: outset;"
+                "padding: 5px"
+                "}"
+            )
             layout.addWidget(self.button)
-        
+
         layout.addWidget(line)
-        
+
         if text:
             text = QLabel(text, self)
             text.setSizePolicy(
@@ -76,4 +86,3 @@ class _QTitleBar(QLabel):
         szh = super().sizeHint()
         szh.setHeight(20)
         return szh
-    
\ No newline at end of file
